# 'Polemarch' documentation

# API

Polemarch provides REST API for all it’s functionality accessible via web GUI, because our GUI also uses this API to work. Below there is an information about every entity we have in Polemarch and methods applicable to it.

This is an example of api schema, but you can find actual schema on Polemarch host at `/api/v2/openapi/`.

## API Paths

`GET` `/community_template/`

  List of community project templates.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "example type",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/community_template/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (ProjectTemplate Schema)

query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/community_template/{pk}/`

  Return a community project template instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "repository": "example repository",
          "description": "example description",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘GIT’, ‘TAR’]) id (integer) – Id name (string) – Name(maxLength=1024, minLength=1) repository (string) – Repository(maxLength=2048, minLength=1) description (string) – Description(minLength=1)

param integer pk(required):
| A unique value identifying this project template.

`POST` `/community_template/{pk}/use_it/`

  Create project based on this template.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "project_id": 1
      }

  JSON Parameters:
  | name (string) – Name(minLength=1) project_id (integer) – Project id(readOnly=True, additionalProperties=OrderedDict([(‘redirect’, True)]))

param integer pk(required):
| A unique value identifying this project template.
query schema data(required):
| ProjectTemplateCreate Schema

`GET` `/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/group/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Contains groups(default=False) notes (textarea) – Notes
  Query Parameters:
  | data(required) (schema) – GroupCreateMaster Schema

`GET` `/group/{pk}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this group.

`PUT` `/group/{pk}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneGroup Schema

`PATCH` `/group/{pk}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneGroup Schema

`DELETE` `/group/{pk}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this group.

`POST` `/group/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "children": true,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True)

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| Group Schema

`GET` `/group/{pk}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/group/1/group/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

param integer pk(required):
| A unique integer value identifying this group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/{pk}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Contains groups(default=False) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| GroupCreateMaster Schema

`GET` `/group/{pk}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.

`PUT` `/group/{pk}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneGroup Schema

`PATCH` `/group/{pk}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneGroup Schema

`DELETE` `/group/{pk}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.

`POST` `/group/{pk}/group/{group_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "children": true,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True)

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| Group Schema

`POST` `/group/{pk}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| SetOwner Schema

`GET` `/group/{pk}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/group/1/group/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/{pk}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| InventoryVariable Schema

`GET` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/group/{pk}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/group/{pk}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/group/1/host/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

param integer pk(required):
| A unique integer value identifying this group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/{pk}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneHost Schema

`GET` `/group/{pk}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.

`PUT` `/group/{pk}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneHost Schema

`PATCH` `/group/{pk}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| OneHost Schema

`DELETE` `/group/{pk}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.

`POST` `/group/{pk}/host/{host_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| Host Schema

`POST` `/group/{pk}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| SetOwner Schema

`GET` `/group/{pk}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/group/1/host/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/{pk}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| InventoryVariable Schema

`GET` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/group/{pk}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`POST` `/group/{pk}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| SetOwner Schema

`GET` `/group/{pk}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/group/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer pk(required):
| A unique integer value identifying this group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/group/{pk}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this group.
query schema data(required):
| InventoryVariable Schema

`GET` `/group/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/group/{pk}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/group/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/group/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this group.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/history/`

  Return all history of executions.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "options": "example options",
                  "project": 1,
                  "mode": "example mode",
                  "executor": 1,
                  "initiator_type": "example initiator_type",
                  "stop_time": "2019-01-07T06:10:31+10:00",
                  "kind": "example kind",
                  "start_time": "2019-01-07T06:10:31+10:00",
                  "inventory": 1,
                  "status": "example status",
                  "initiator": 1
              }
          ],
          "next": "http://localhost:8080/history/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (History Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string mode:
| Module or playbook name.
query string kind:
| Kind of execution.
query string status:
| Status of execution.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string name:
| A name string value (or comma separated list) of instance.
query string older:
| Older then this time
query string newer:
| Newer then this time
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/history/{pk}/`

  Return a execution history instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "raw_args": "example raw_args",
          "id": 1,
          "revision": "example revision",
          "raw_inventory": "example raw_inventory",
          "options": "example options",
          "inventory": 1,
          "raw_stdout": "example raw_stdout",
          "executor": 1,
          "project": 1,
          "execute_args": "example execute_args",
          "stop_time": "2019-01-07T06:10:31+10:00",
          "execution_time": "22:11:34",
          "initiator": 1,
          "start_time": "2019-01-07T06:10:31+10:00",
          "mode": "example mode",
          "initiator_type": "example initiator_type",
          "status": "example status",
          "kind": "example kind"
      }

  JSON Parameters:
  | kind (string) – Kind(maxLength=50, minLength=1) execution_time (uptime) – Execution time initiator (integer) – Initiator executor (integer) – Executor initiator_type (string) – Initiator type(maxLength=50, minLength=1) mode (string) – Mode(maxLength=256, minLength=1) status (string) – Status(enum=[‘DELAY’, ‘RUN’, ‘OK’, ‘ERROR’, ‘OFFLINE’, ‘INTERRUPTED’]) raw_args (string) – Raw args(minLength=1) raw_stdout (string) – Raw stdout(readOnly=True) options (string) – Options(readOnly=True) inventory (integer) – Inventory execute_args (string) – Execute args(readOnly=True) stop_time (date-time) – Stop time revision (string) – Revision(maxLength=256) project (integer) – Project id (integer) – Id(readOnly=True) raw_inventory (string) – Raw inventory(minLength=1) start_time (date-time) – Start time

param integer pk(required):
| A unique integer value identifying this history.

`DELETE` `/history/{pk}/`

  Remove an existing history record.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this history.

`POST` `/history/{pk}/cancel/`

  Cencel working task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters:
  | detail (string) – Detail(minLength=1)

param integer pk(required):
| A unique integer value identifying this history.
query schema data(required):
| Empty Schema

`DELETE` `/history/{pk}/clear/`

  Clear history output.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this history.

`GET` `/history/{pk}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this history.

`GET` `/hook/`

  Return all hooks.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "example type",
                  "id": 1,
                  "when": "example when",
                  "name": "example name",
                  "recipients": "example recipients",
                  "enable": true
              }
          ],
          "next": "http://localhost:8080/hook/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Hook Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/hook/`

  Create a new hook.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "when": "example when",
          "name": "example name",
          "recipients": "example recipients",
          "enable": true
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) enable (boolean) – Enable type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’]) recipients (string) – Recipients(minLength=1) when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’]) id (integer) – Id(readOnly=True)
  Query Parameters:
  | data(required) (schema) – Hook Schema

`GET` `/hook/{pk}/`

  Return a hook instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "when": "example when",
          "name": "example name",
          "recipients": "example recipients",
          "enable": true
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) enable (boolean) – Enable type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’]) recipients (string) – Recipients(minLength=1) when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’]) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this hook.

`PUT` `/hook/{pk}/`

  Update a hook.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "when": "example when",
          "name": "example name",
          "recipients": "example recipients",
          "enable": true
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) enable (boolean) – Enable type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’]) recipients (string) – Recipients(minLength=1) when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’]) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this hook.
query schema data(required):
| Hook Schema

`PATCH` `/hook/{pk}/`

  Update one or more fields on an existing hook.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "when": "example when",
          "name": "example name",
          "recipients": "example recipients",
          "enable": true
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) enable (boolean) – Enable type (string) – Type(enum=[‘HTTP’, ‘SCRIPT’]) recipients (string) – Recipients(minLength=1) when (string) – When(enum=[‘on_execution’, ‘after_execution’, ‘on_user_add’, ‘on_user_upd’, ‘on_user_del’, ‘on_object_add’, ‘on_object_upd’, ‘on_object_del’]) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this hook.
query schema data(required):
| Hook Schema

`DELETE` `/hook/{pk}/`

  Remove an existing hook.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this hook.

`GET` `/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/host/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes
  Query Parameters:
  | data(required) (schema) – OneHost Schema

`GET` `/host/{pk}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this host.

`PUT` `/host/{pk}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this host.
query schema data(required):
| OneHost Schema

`PATCH` `/host/{pk}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this host.
query schema data(required):
| OneHost Schema

`DELETE` `/host/{pk}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this host.

`POST` `/host/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param integer pk(required):
| A unique integer value identifying this host.
query schema data(required):
| Host Schema

`POST` `/host/{pk}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer pk(required):
| A unique integer value identifying this host.
query schema data(required):
| SetOwner Schema

`GET` `/host/{pk}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/host/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer pk(required):
| A unique integer value identifying this host.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/host/{pk}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this host.
query schema data(required):
| InventoryVariable Schema

`GET` `/host/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this host.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/host/{pk}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this host.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/host/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this host.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/host/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this host.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/inventory/`

  Return all inventories.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/inventory/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Inventory Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes
  Query Parameters:
  | data(required) (schema) – OneInventory Schema

`POST` `/inventory/import_inventory/`

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "inventory_id": 1,
          "raw_data": "example raw_data"
      }

  JSON Parameters:
  | name (string) – Name(minLength=1) inventory_id (integer) – Inventory id(additionalProperties=OrderedDict([(‘redirect’, True)])) raw_data (string) – Raw data(minLength=1)
  Query Parameters:
  | data(required) (schema) – InventoryImport Schema

`GET` `/inventory/{pk}/`

  Return a inventory instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this inventory.

`PUT` `/inventory/{pk}/`

  Update a inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneInventory Schema

`PATCH` `/inventory/{pk}/`

  Update one or more fields on an existing inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneInventory Schema

`DELETE` `/inventory/{pk}/`

  Remove an existing inventory.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this inventory.

`GET` `/inventory/{pk}/all_groups/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/inventory/1/all_groups/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/inventory/{pk}/all_groups/{all_groups_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param string all_groups_id(required):
param integer pk(required):
| A unique integer value identifying this inventory.

`GET` `/inventory/{pk}/all_hosts/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/inventory/1/all_hosts/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/inventory/{pk}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param string all_hosts_id(required):
param integer pk(required):
| A unique integer value identifying this inventory.

`POST` `/inventory/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| Inventory Schema

`GET` `/inventory/{pk}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/inventory/1/group/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/{pk}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Contains groups(default=False) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| GroupCreateMaster Schema

`GET` `/inventory/{pk}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.

`PUT` `/inventory/{pk}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneGroup Schema

`PATCH` `/inventory/{pk}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneGroup Schema

`DELETE` `/inventory/{pk}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.

`POST` `/inventory/{pk}/group/{group_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "children": true,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True)

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| Group Schema

`POST` `/inventory/{pk}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| SetOwner Schema

`GET` `/inventory/{pk}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/inventory/1/group/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/{pk}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| InventoryVariable Schema

`GET` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/inventory/{pk}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer group_id(required):
| A unique integer value identifying instance of this groups sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/inventory/{pk}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/inventory/1/host/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/{pk}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneHost Schema

`GET` `/inventory/{pk}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.

`PUT` `/inventory/{pk}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneHost Schema

`PATCH` `/inventory/{pk}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| OneHost Schema

`DELETE` `/inventory/{pk}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.

`POST` `/inventory/{pk}/host/{host_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| Host Schema

`POST` `/inventory/{pk}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| SetOwner Schema

`GET` `/inventory/{pk}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/inventory/1/host/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/{pk}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| InventoryVariable Schema

`GET` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/inventory/{pk}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer host_id(required):
| A unique integer value identifying instance of this hosts sublist.
param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`POST` `/inventory/{pk}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| SetOwner Schema

`GET` `/inventory/{pk}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/inventory/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer pk(required):
| A unique integer value identifying this inventory.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/inventory/{pk}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this inventory.
query schema data(required):
| InventoryVariable Schema

`GET` `/inventory/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/inventory/{pk}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/inventory/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/inventory/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this inventory.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/project/`

  Return all projects.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "example type",
                  "id": 1,
                  "status": "example status",
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Project Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string status:
| Project sync status.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string status__not:
| Project sync status.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/`

  Create a new project.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "MANUAL",
          "id": 1,
          "repo_auth": "NONE",
          "branch": "test_dynamic",
          "auth_data": "test_dynamic",
          "name": "example name",
          "repository": "MANUAL",
          "status": "example status"
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) type (string) – Repo type(enum=[‘GIT’, ‘MANUAL’, ‘TAR’], default=MANUAL) status (string) – Status(readOnly=True, minLength=1) repo_auth (dynamic) – Repo auth type branch (dynamic) – GIT branch/tag/SHA id (integer) – Id(readOnly=True) auth_data (dynamic) – Repo auth data repository (string) – Repo url(default=MANUAL, minLength=1)
  Query Parameters:
  | data(required) (schema) – ProjectCreateMaster Schema

`GET` `/project/{pk}/`

  Return a project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "revision": "example revision",
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "branch": "example branch",
          "execute_view_data": {},
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "repository": "MANUAL",
          "status": "example status",
          "readme_content": "test_html"
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) readme_content (html) – Information(readOnly=True) notes (textarea) – Notes status (string) – Status(enum=[‘NEW’, ‘WAIT_SYNC’, ‘SYNC’, ‘ERROR’, ‘OK’], readOnly=True) execute_view_data (object) – (Data Schema) branch (string) – Branch(readOnly=True) revision (string) – Revision(readOnly=True) owner (object) – (User Schema) id (integer) – Id(readOnly=True) repository (string) – Repository(default=MANUAL, minLength=1)

param integer pk(required):
| A unique integer value identifying this project.

`PUT` `/project/{pk}/`

  Update a project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "revision": "example revision",
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "branch": "example branch",
          "execute_view_data": {},
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "repository": "MANUAL",
          "status": "example status",
          "readme_content": "test_html"
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) readme_content (html) – Information(readOnly=True) notes (textarea) – Notes status (string) – Status(enum=[‘NEW’, ‘WAIT_SYNC’, ‘SYNC’, ‘ERROR’, ‘OK’], readOnly=True) execute_view_data (object) – (Data Schema) branch (string) – Branch(readOnly=True) revision (string) – Revision(readOnly=True) owner (object) – (User Schema) id (integer) – Id(readOnly=True) repository (string) – Repository(default=MANUAL, minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneProject Schema

`PATCH` `/project/{pk}/`

  Update one or more fields on an existing project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "revision": "example revision",
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "branch": "example branch",
          "execute_view_data": {},
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "repository": "MANUAL",
          "status": "example status",
          "readme_content": "test_html"
      }

  JSON Parameters:
  | name (string) – Name(maxLength=512, minLength=1) readme_content (html) – Information(readOnly=True) notes (textarea) – Notes status (string) – Status(enum=[‘NEW’, ‘WAIT_SYNC’, ‘SYNC’, ‘ERROR’, ‘OK’], readOnly=True) execute_view_data (object) – (Data Schema) branch (string) – Branch(readOnly=True) revision (string) – Revision(readOnly=True) owner (object) – (User Schema) id (integer) – Id(readOnly=True) repository (string) – Repository(default=MANUAL, minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneProject Schema

`DELETE` `/project/{pk}/`

  Remove an existing project.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "example type",
          "id": 1,
          "status": "example status",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(readOnly=True, minLength=1) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) status (string) – Status(enum=[‘NEW’, ‘WAIT_SYNC’, ‘SYNC’, ‘ERROR’, ‘OK’], readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Project Schema

`POST` `/project/{pk}/execute_module/`

  Execute ansible -m [module] with arguments.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "executor": 1,
          "history_id": 1
      }

  JSON Parameters:
  | executor (integer) – Executor history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)])) detail (string) – Detail(minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| AnsibleModule Schema

`POST` `/project/{pk}/execute_playbook/`

  Execute ansible-playbook with arguments.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "executor": 1,
          "history_id": 1
      }

  JSON Parameters:
  | executor (integer) – Executor history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)])) detail (string) – Detail(minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| AnsiblePlaybook Schema

`GET` `/project/{pk}/history/`

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "revision": "example revision",
                  "options": "example options",
                  "inventory": 1,
                  "executor": 1,
                  "initiator_type": "example initiator_type",
                  "stop_time": "2019-01-07T06:10:31+10:00",
                  "kind": "example kind",
                  "start_time": "2019-01-07T06:10:31+10:00",
                  "mode": "example mode",
                  "status": "example status",
                  "initiator": 1
              }
          ],
          "next": "http://localhost:8080/project/1/history/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (ProjectHistory Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string mode:
| Module or playbook name.
query string kind:
| Kind of execution.
query string status:
| Status of execution.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string name:
| A name string value (or comma separated list) of instance.
query string older:
| Older then this time
query string newer:
| Newer then this time
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/project/{pk}/history/{history_id}/`

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "raw_args": "example raw_args",
          "id": 1,
          "revision": "example revision",
          "raw_inventory": "example raw_inventory",
          "options": "example options",
          "inventory": 1,
          "raw_stdout": "example raw_stdout",
          "executor": 1,
          "project": 1,
          "execute_args": "example execute_args",
          "stop_time": "2019-01-07T06:10:31+10:00",
          "execution_time": "22:11:34",
          "initiator": 1,
          "start_time": "2019-01-07T06:10:31+10:00",
          "mode": "example mode",
          "initiator_type": "example initiator_type",
          "status": "example status",
          "kind": "example kind"
      }

  JSON Parameters:
  | kind (string) – Kind(maxLength=50, minLength=1) execution_time (uptime) – Execution time initiator (integer) – Initiator executor (integer) – Executor initiator_type (string) – Initiator type(maxLength=50, minLength=1) mode (string) – Mode(maxLength=256, minLength=1) status (string) – Status(enum=[‘DELAY’, ‘RUN’, ‘OK’, ‘ERROR’, ‘OFFLINE’, ‘INTERRUPTED’]) raw_args (string) – Raw args(minLength=1) raw_stdout (string) – Raw stdout(readOnly=True) options (string) – Options(readOnly=True) inventory (integer) – Inventory execute_args (string) – Execute args(readOnly=True) stop_time (date-time) – Stop time revision (string) – Revision(maxLength=256) project (integer) – Project id (integer) – Id(readOnly=True) raw_inventory (string) – Raw inventory(minLength=1) start_time (date-time) – Start time

param integer history_id(required):
| A unique integer value identifying instance of this history sublist.
param integer pk(required):
| A unique integer value identifying this project.

`DELETE` `/project/{pk}/history/{history_id}/`

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required):
| A unique integer value identifying instance of this history sublist.
param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/history/{history_id}/cancel/`

  Cencel working task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters:
  | detail (string) – Detail(minLength=1)

param integer history_id(required):
| A unique integer value identifying instance of this history sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Empty Schema

`DELETE` `/project/{pk}/history/{history_id}/clear/`

  Clear history output.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required):
| A unique integer value identifying instance of this history sublist.
param integer pk(required):
| A unique integer value identifying this project.

`GET` `/project/{pk}/history/{history_id}/facts/`

  Get compilated history facts (only for execution ‘module’ with module ‘setup’).

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer history_id(required):
| A unique integer value identifying instance of this history sublist.
param integer pk(required):
| A unique integer value identifying this project.

`GET` `/project/{pk}/inventory/`

  Return all inventories.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Inventory Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneInventory Schema

`POST` `/project/{pk}/inventory/import_inventory/`

  Create a new inventory.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "name": "example name",
          "inventory_id": 1,
          "raw_data": "example raw_data"
      }

  JSON Parameters:
  | name (string) – Name(minLength=1) inventory_id (integer) – Inventory id(additionalProperties=OrderedDict([(‘redirect’, True)])) raw_data (string) – Raw data(minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| InventoryImport Schema

`GET` `/project/{pk}/inventory/{inventory_id}/`

  Return a inventory instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`PUT` `/project/{pk}/inventory/{inventory_id}/`

  Update a inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneInventory Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/`

  Update one or more fields on an existing inventory.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) notes (textarea) – Notes

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneInventory Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/`

  Remove an existing inventory.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`GET` `/project/{pk}/inventory/{inventory_id}/all_groups/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/all_groups/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/project/{pk}/inventory/{inventory_id}/all_groups/{all_groups_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param string all_groups_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`GET` `/project/{pk}/inventory/{inventory_id}/all_hosts/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/all_hosts/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/project/{pk}/inventory/{inventory_id}/all_hosts/{all_hosts_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param string all_hosts_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/inventory/{inventory_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Inventory Schema

`GET` `/project/{pk}/inventory/{inventory_id}/group/`

  Return all groups.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "children": true,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/group/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Group Schema)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/{inventory_id}/group/`

  Create a new group.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Contains groups(default=False) notes (textarea) – Notes

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| GroupCreateMaster Schema

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Return a group instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`PUT` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Update a group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneGroup Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Update one or more fields on an existing group.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "id": 1,
          "children": true,
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True) notes (textarea) – Notes

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneGroup Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/`

  Remove an existing group.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "children": true,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) children (boolean) – Children(readOnly=True)

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Group Schema

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| SetOwner Schema

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/group/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| InventoryVariable Schema

`GET` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/group/{group_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string group_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/project/{pk}/inventory/{inventory_id}/host/`

  Return all hosts.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "HOST",
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/host/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Host Schema)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string type:
| Instance type.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string variables:
| List of variables to filter. Comma separeted “key:value” list.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/{inventory_id}/host/`

  Create a new host.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneHost Schema

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Return a host instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`PUT` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Update a host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneHost Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Update one or more fields on an existing host.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1) owner (object) – (User Schema) notes (textarea) – Notes

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneHost Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/`

  Remove an existing host.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "HOST",
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | type (string) – Type(enum=[‘RANGE’, ‘HOST’], default=HOST) id (integer) – Id(readOnly=True) name (string) – Name(maxLength=512, minLength=1)

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Host Schema

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| SetOwner Schema

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/host/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| InventoryVariable Schema

`GET` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/host/{host_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string host_id(required):
param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`POST` `/project/{pk}/inventory/{inventory_id}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| SetOwner Schema

`GET` `/project/{pk}/inventory/{inventory_id}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "ansible_host",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/project/1/inventory/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (InventoryVariable Schema)

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/inventory/{inventory_id}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| InventoryVariable Schema

`GET` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`PATCH` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "ansible_host",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (autocomplete) – Key(Example values: ansible_host, ansible_port, ansible_user, ansible_connection, ansible_ssh_pass, ansible_ssh_private_key_file, ansible_ssh_common_args, ansible_sftp_extra_args, ansible_scp_extra_args, ansible_ssh_extra_args, ansible_ssh_executable, ansible_ssh_pipelining, ansible_become, ansible_become_method, ansible_become_user, ansible_become_pass, ansible_become_exe, ansible_become_flags, ansible_shell_type, ansible_python_interpreter, ansible_ruby_interpreter, ansible_perl_interpreter, ansible_shell_executable) value (dynamic) – Value

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| InventoryVariable Schema

`DELETE` `/project/{pk}/inventory/{inventory_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer inventory_id(required):
| A unique integer value identifying instance of this inventories sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/project/{pk}/module/`

  Return all available modules of project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "path": "example path",
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/module/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Module Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string path:
| Full path to module.
query string path__not:
| Full path to module.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/project/{pk}/module/{module_id}/`

  Return a module details of project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "data": {},
          "id": 1,
          "path": "example path",
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) name (string) – Name(readOnly=True) data (object) – (Data Schema) path (string) – Path(maxLength=1024, minLength=1)

param string module_id(required):
param integer pk(required):
| A unique integer value identifying this project.

`GET` `/project/{pk}/periodic_task/`

  Return all periodic tasks in project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "type": "CRONTAB",
                  "id": 1,
                  "inventory": "test_dynamic",
                  "template": 1,
                  "enabled": true,
                  "save_result": true,
                  "template_opt": "test_dynamic",
                  "mode": "test_dynamic",
                  "name": "example name",
                  "schedule": "test_dynamic",
                  "kind": "PLAYBOOK"
              }
          ],
          "next": "http://localhost:8080/project/1/periodic_task/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Periodictask Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string mode:
| Periodic task module or playbook name.
query string kind:
| Kind of periodic task.
query string type:
| Instance type.
query number template:
| A unique integer id of template used in periodic task.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string name:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/periodic_task/`

  Create a new periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "CRONTAB",
          "id": 1,
          "inventory": "test_dynamic",
          "template": 1,
          "enabled": true,
          "save_result": true,
          "template_opt": "test_dynamic",
          "notes": "example\ntext\narea\n",
          "mode": "test_dynamic",
          "name": "example name",
          "schedule": "test_dynamic",
          "kind": "PLAYBOOK"
      }

  JSON Parameters:
  | kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK) name (string) – Name(maxLength=512, minLength=1) mode (dynamic) – Mode save_result (boolean) – Save result schedule (dynamic) – Schedule notes (textarea) – Notes inventory (dynamic) – Inventory type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB) enabled (boolean) – Enabled template_opt (dynamic) – Template opt template (integer) – Template id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OnePeriodictask Schema

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Return a perodic task instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "CRONTAB",
          "id": 1,
          "inventory": "test_dynamic",
          "template": 1,
          "enabled": true,
          "save_result": true,
          "template_opt": "test_dynamic",
          "notes": "example\ntext\narea\n",
          "mode": "test_dynamic",
          "name": "example name",
          "schedule": "test_dynamic",
          "kind": "PLAYBOOK"
      }

  JSON Parameters:
  | kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK) name (string) – Name(maxLength=512, minLength=1) mode (dynamic) – Mode save_result (boolean) – Save result schedule (dynamic) – Schedule notes (textarea) – Notes inventory (dynamic) – Inventory type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB) enabled (boolean) – Enabled template_opt (dynamic) – Template opt template (integer) – Template id (integer) – Id(readOnly=True)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.

`PUT` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Update a periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "CRONTAB",
          "id": 1,
          "inventory": "test_dynamic",
          "template": 1,
          "enabled": true,
          "save_result": true,
          "template_opt": "test_dynamic",
          "notes": "example\ntext\narea\n",
          "mode": "test_dynamic",
          "name": "example name",
          "schedule": "test_dynamic",
          "kind": "PLAYBOOK"
      }

  JSON Parameters:
  | kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK) name (string) – Name(maxLength=512, minLength=1) mode (dynamic) – Mode save_result (boolean) – Save result schedule (dynamic) – Schedule notes (textarea) – Notes inventory (dynamic) – Inventory type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB) enabled (boolean) – Enabled template_opt (dynamic) – Template opt template (integer) – Template id (integer) – Id(readOnly=True)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OnePeriodictask Schema

`PATCH` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Update one or more fields on an existing periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "type": "CRONTAB",
          "id": 1,
          "inventory": "test_dynamic",
          "template": 1,
          "enabled": true,
          "save_result": true,
          "template_opt": "test_dynamic",
          "notes": "example\ntext\narea\n",
          "mode": "test_dynamic",
          "name": "example name",
          "schedule": "test_dynamic",
          "kind": "PLAYBOOK"
      }

  JSON Parameters:
  | kind (string) – Task type(enum=[‘PLAYBOOK’, ‘MODULE’, ‘TEMPLATE’], default=PLAYBOOK) name (string) – Name(maxLength=512, minLength=1) mode (dynamic) – Mode save_result (boolean) – Save result schedule (dynamic) – Schedule notes (textarea) – Notes inventory (dynamic) – Inventory type (string) – Interval type(enum=[‘CRONTAB’, ‘INTERVAL’], default=CRONTAB) enabled (boolean) – Enabled template_opt (dynamic) – Template opt template (integer) – Template id (integer) – Id(readOnly=True)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OnePeriodictask Schema

`DELETE` `/project/{pk}/periodic_task/{periodic_task_id}/`

  Remove an existing periodic task.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.

`POST` `/project/{pk}/periodic_task/{periodic_task_id}/execute/`

  Ad-hoc execute periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "executor": 1,
          "history_id": 1
      }

  JSON Parameters:
  | executor (integer) – Executor history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)])) detail (string) – Detail(minLength=1)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Empty Schema

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/variables/`

  Return all variables of periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "example key",
                  "value": "example value"
              }
          ],
          "next": "http://localhost:8080/project/1/periodic_task/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (PeriodicTaskVariable Schema)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/periodic_task/{periodic_task_id}/variables/`

  Create a new variable of periodic task.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "example value"
      }

  JSON Parameters:
  | value (string) – Value(default=) id (integer) – Id(readOnly=True) key (string) – Key(maxLength=512, minLength=1)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| PeriodicTaskVariable Schema

`GET` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Return a variable of periodic task.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "example value"
      }

  JSON Parameters:
  | value (string) – Value(default=) id (integer) – Id(readOnly=True) key (string) – Key(maxLength=512, minLength=1)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "example value"
      }

  JSON Parameters:
  | value (string) – Value(default=) id (integer) – Id(readOnly=True) key (string) – Key(maxLength=512, minLength=1)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| PeriodicTaskVariable Schema

`PATCH` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "example value"
      }

  JSON Parameters:
  | value (string) – Value(default=) id (integer) – Id(readOnly=True) key (string) – Key(maxLength=512, minLength=1)

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| PeriodicTaskVariable Schema

`DELETE` `/project/{pk}/periodic_task/{periodic_task_id}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer periodic_task_id(required):
| A unique integer value identifying instance of this periodic_task sublist.
param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/project/{pk}/playbook/`

  Return all playbooks of project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "playbook": "example playbook",
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/project/1/playbook/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Playbook Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string playbook:
| Playbook filename.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string playbook__not:
| Playbook filename.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`GET` `/project/{pk}/playbook/{playbook_id}/`

  Return a playbook of project instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "playbook": "example playbook",
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) playbook (string) – Playbook(readOnly=True, minLength=1) name (string) – Name(maxLength=251, minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
param integer playbook_id(required):
| A unique integer value identifying instance of this playbook sublist.

`POST` `/project/{pk}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| SetOwner Schema

`POST` `/project/{pk}/sync/`

  Sync project with repository.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail"
      }

  JSON Parameters:
  | detail (string) – Detail(minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| Empty Schema

`GET` `/project/{pk}/template/`

  Return all execute templates in project.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "data": {},
                  "id": 1,
                  "options": {},
                  "options_list": [
                      "array_example"
                  ],
                  "name": "example name",
                  "kind": "Task"
              }
          ],
          "next": "http://localhost:8080/project/1/template/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Template Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string kind:
| A kind of template.
query string inventory:
| The inventory id or path in project.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/template/`

  Create a new execute template.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "data": {},
          "id": 1,
          "options": {},
          "options_list": [
              "array_example"
          ],
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "kind": "Task"
      }

  JSON Parameters:
  | kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task) name (string) – Name(maxLength=512, minLength=1) options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True) notes (textarea) – Notes data (object) – (Data Schema) options (object) – (Data Schema) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| OneTemplate Schema

`GET` `/project/{pk}/template/{template_id}/`

  Return a execute template instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "data": {},
          "id": 1,
          "options": {},
          "options_list": [
              "array_example"
          ],
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "kind": "Task"
      }

  JSON Parameters:
  | kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task) name (string) – Name(maxLength=512, minLength=1) options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True) notes (textarea) – Notes data (object) – (Data Schema) options (object) – (Data Schema) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
param integer template_id(required):
| A unique integer value identifying instance of this template sublist.

`PUT` `/project/{pk}/template/{template_id}/`

  Update a execute template.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "data": {},
          "id": 1,
          "options": {},
          "options_list": [
              "array_example"
          ],
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "kind": "Task"
      }

  JSON Parameters:
  | kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task) name (string) – Name(maxLength=512, minLength=1) options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True) notes (textarea) – Notes data (object) – (Data Schema) options (object) – (Data Schema) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
param integer template_id(required):
| A unique integer value identifying instance of this template sublist.
query schema data(required):
| OneTemplate Schema

`PATCH` `/project/{pk}/template/{template_id}/`

  Update one or more fields on an existing execute template.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "data": {},
          "id": 1,
          "options": {},
          "options_list": [
              "array_example"
          ],
          "notes": "example\ntext\narea\n",
          "name": "example name",
          "kind": "Task"
      }

  JSON Parameters:
  | kind (string) – Type(enum=[‘Task’, ‘Module’], default=Task) name (string) – Name(maxLength=512, minLength=1) options_list (array) – (items=OrderedDict([(‘type’, ‘string’)]), readOnly=True) notes (textarea) – Notes data (object) – (Data Schema) options (object) – (Data Schema) id (integer) – Id(readOnly=True)

param integer pk(required):
| A unique integer value identifying this project.
param integer template_id(required):
| A unique integer value identifying instance of this template sublist.
query schema data(required):
| OneTemplate Schema

`DELETE` `/project/{pk}/template/{template_id}/`

  Remove an existing execute template.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this project.
param integer template_id(required):
| A unique integer value identifying instance of this template sublist.

`POST` `/project/{pk}/template/{template_id}/execute/`

  Execute template with option.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "detail": "example detail",
          "executor": 1,
          "history_id": 1
      }

  JSON Parameters:
  | executor (integer) – Executor history_id (integer) – History id(additionalProperties=OrderedDict([(‘redirect’, True)])) detail (string) – Detail(minLength=1)

param integer pk(required):
| A unique integer value identifying this project.
param integer template_id(required):
| A unique integer value identifying instance of this template sublist.
query schema data(required):
| TemplateExec Schema

`GET` `/project/{pk}/variables/`

  Return all variables of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "key": "example key",
                  "value": "test_dynamic"
              }
          ],
          "next": "http://localhost:8080/project/1/variables/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (ProjectVariable Schema)

param integer pk(required):
| A unique integer value identifying this project.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string key:
| A key name string value (or comma separated list) of instance.
query string value:
| A value of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/project/{pk}/variables/`

  Create a new variable of instance.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (string) – Key(enum=[‘repo_type’, ‘repo_sync_on_run’, ‘repo_branch’, ‘repo_password’, ‘repo_key’]) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this project.
query schema data(required):
| ProjectVariable Schema

`GET` `/project/{pk}/variables/{variables_id}/`

  Return a variable of instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (string) – Key(enum=[‘repo_type’, ‘repo_sync_on_run’, ‘repo_branch’, ‘repo_password’, ‘repo_key’]) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`PUT` `/project/{pk}/variables/{variables_id}/`

  Update variable value.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (string) – Key(enum=[‘repo_type’, ‘repo_sync_on_run’, ‘repo_branch’, ‘repo_password’, ‘repo_key’]) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| ProjectVariable Schema

`PATCH` `/project/{pk}/variables/{variables_id}/`

  Update one or more fields on an existing variable.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "key": "example key",
          "value": "test_dynamic"
      }

  JSON Parameters:
  | id (integer) – Id(readOnly=True) key (string) – Key(enum=[‘repo_type’, ‘repo_sync_on_run’, ‘repo_branch’, ‘repo_password’, ‘repo_key’]) value (dynamic) – Value

param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.
query schema data(required):
| ProjectVariable Schema

`DELETE` `/project/{pk}/variables/{variables_id}/`

  Remove an existing variable.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this project.
param integer variables_id(required):
| A unique integer value identifying instance of this variables sublist.

`GET` `/team/`

  Return all teams.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "id": 1,
                  "name": "example name"
              }
          ],
          "next": "http://localhost:8080/team/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (Team Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string name:
| A name string value (or comma separated list) of instance.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string name__not:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/team/`

  Create a new team.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – ID(readOnly=True) name (string) – Name(maxLength=80, minLength=1) notes (textarea) – Notes
  Query Parameters:
  | data(required) (schema) – OneTeam Schema

`GET` `/team/{pk}/`

  Return a team instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – ID(readOnly=True) name (string) – Name(maxLength=80, minLength=1) notes (textarea) – Notes

param string pk(required):
| A unique value identifying this user group.

`PUT` `/team/{pk}/`

  Update a team.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – ID(readOnly=True) name (string) – Name(maxLength=80, minLength=1) notes (textarea) – Notes

param string pk(required):
| A unique value identifying this user group.
query schema data(required):
| OneTeam Schema

`PATCH` `/team/{pk}/`

  Update one or more fields on an existing team.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "owner": {
              "is_active": true,
              "id": 1,
              "username": "example username",
              "email": "example@mail.com"
          },
          "notes": "example\ntext\narea\n",
          "name": "example name"
      }

  JSON Parameters:
  | owner (object) – (User Schema) id (integer) – ID(readOnly=True) name (string) – Name(maxLength=80, minLength=1) notes (textarea) – Notes

param string pk(required):
| A unique value identifying this user group.
query schema data(required):
| OneTeam Schema

`DELETE` `/team/{pk}/`

  Remove an existing team.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string pk(required):
| A unique value identifying this user group.

`POST` `/team/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "name": "example name"
      }

  JSON Parameters:
  | id (integer) – ID(readOnly=True) name (string) – Name(maxLength=80, minLength=1)

param string pk(required):
| A unique value identifying this user group.
query schema data(required):
| Team Schema

`POST` `/team/{pk}/set_owner/`

  Change instance owner.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "user_id": 1
      }

  JSON Parameters:
  | user_id (select2) – New owner

param string pk(required):
| A unique value identifying this user group.
query schema data(required):
| SetOwner Schema

`GET` `/team/{pk}/user/`

  Return all users.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "is_active": true,
                  "id": 1,
                  "username": "example username",
                  "email": "example@mail.com"
              }
          ],
          "next": "http://localhost:8080/team/1/user/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (User Schema)

param string pk(required):
| A unique value identifying this user group.
query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string username:
| A name string value (or comma separated list) of instance.
query string is_active:
| Boolean value meaning status of user.
query string first_name:
| Users first name.
query string last_name:
| Users last name.
query string email:
| Users e-mail value.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string username__not:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/team/{pk}/user/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "password": "example password",
          "is_active": true,
          "password2": "example password2",
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) password (string) – Password(minLength=1) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) password2 (string) – Repeat password(minLength=1) email (email) – Email(minLength=1)

param string pk(required):
| A unique value identifying this user group.
query schema data(required):
| CreateUser Schema

`GET` `/team/{pk}/user/{user_id}/`

  Return a user instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.

`PUT` `/team/{pk}/user/{user_id}/`

  Update a user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.
query schema data(required):
| OneUser Schema

`PATCH` `/team/{pk}/user/{user_id}/`

  Update one or more fields on an existing user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.
query schema data(required):
| OneUser Schema

`DELETE` `/team/{pk}/user/{user_id}/`

  Remove an existing user.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.

`POST` `/team/{pk}/user/{user_id}/change_password/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "old_password": "example old_password",
          "password2": "example password2",
          "password": "example password"
      }

  JSON Parameters:
  | old_password (string) – Old password(minLength=1) password2 (string) – Confirm new password(minLength=1) password (string) – New password(minLength=1)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.
query schema data(required):
| ChangePassword Schema

`POST` `/team/{pk}/user/{user_id}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "is_active": true,
          "id": 1,
          "username": "example username",
          "email": "example@mail.com"
      }

  JSON Parameters:
  | id (integer) – ID(readOnly=True) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) email (email) – Email(minLength=1)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.
query schema data(required):
| User Schema

`GET` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. For example: from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "offline": {
                  "active": true
              },
              "error": {
                  "active": true
              },
              "delay": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              }
          },
          "widgetSettings": {
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwProjectsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              }
          },
          "autoupdateInterval": 15000
      }

  JSON Parameters:
  | chartLineSettings (object) – (ChartLineSettings Schema) widgetSettings (object) – (WidgetSettings Schema) autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.

`POST` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. For example: from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "offline": {
                  "active": true
              },
              "error": {
                  "active": true
              },
              "delay": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              }
          },
          "widgetSettings": {
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwProjectsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              }
          },
          "autoupdateInterval": 15000
      }

  JSON Parameters:
  | chartLineSettings (object) – (ChartLineSettings Schema) widgetSettings (object) – (WidgetSettings Schema) autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.
query schema data(required):
| UserSettings Schema

`DELETE` `/team/{pk}/user/{user_id}/settings/`

  A settings object, that allows API settings to be accessed as properties. For example: from rest_framework.settings import api_settings print(api_settings.DEFAULT_RENDERER_CLASSES) Any setting with string import paths will be automatically resolved and return the class, rather than the string literal.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param string pk(required):
| A unique value identifying this user group.
param integer user_id(required):
| A unique integer value identifying instance of this users sublist.

`GET` `/user/`

  Return all users.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "results": [
              {
                  "is_active": true,
                  "id": 1,
                  "username": "example username",
                  "email": "example@mail.com"
              }
          ],
          "next": "http://localhost:8080/user/?limit=1&offset=1",
          "count": 2,
          "previous": null
      }

  JSON Parameters:
  | count (integer) – None next (uri) – None previous (uri) – None results (array) – (User Schema)

query string id:
| A unique integer value (or comma separated list) identifying this instance.
query string username:
| A name string value (or comma separated list) of instance.
query string is_active:
| Boolean value meaning status of user.
query string first_name:
| Users first name.
query string last_name:
| Users last name.
query string email:
| Users e-mail value.
query string id__not:
| A unique integer value (or comma separated list) identifying this instance.
query string username__not:
| A name string value (or comma separated list) of instance.
query string ordering:
| Which field to use when ordering the results.
query integer limit:
| Number of results to return per page.
query integer offset:
| The initial index from which to return the results.

`POST` `/user/`

  Create a new user.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "password": "example password",
          "is_active": true,
          "password2": "example password2",
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) password (string) – Password(minLength=1) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) password2 (string) – Repeat password(minLength=1) email (email) – Email(minLength=1)
  Query Parameters:
  | data(required) (schema) – CreateUser Schema

`GET` `/user/{pk}/`

  Return a user instance.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param integer pk(required):
| A unique integer value identifying this user.

`PUT` `/user/{pk}/`

  Update a user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param integer pk(required):
| A unique integer value identifying this user.
query schema data(required):
| OneUser Schema

`PATCH` `/user/{pk}/`

  Update one or more fields on an existing user.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "id": 1,
          "email": "example@mail.com",
          "is_active": true,
          "username": "example username",
          "first_name": "example first_name",
          "last_name": "example last_name"
      }

  JSON Parameters:
  | last_name (string) – Last name(maxLength=30) first_name (string) – First name(maxLength=30) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) id (integer) – ID(readOnly=True) email (email) – Email(minLength=1)

param integer pk(required):
| A unique integer value identifying this user.
query schema data(required):
| OneUser Schema

`DELETE` `/user/{pk}/`

  Remove an existing user.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this user.

`POST` `/user/{pk}/change_password/`

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "old_password": "example old_password",
          "password2": "example password2",
          "password": "example password"
      }

  JSON Parameters:
  | old_password (string) – Old password(minLength=1) password2 (string) – Confirm new password(minLength=1) password (string) – New password(minLength=1)

param integer pk(required):
| A unique integer value identifying this user.
query schema data(required):
| ChangePassword Schema

`POST` `/user/{pk}/copy/`

  Copy instance with deps.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "is_active": true,
          "id": 1,
          "username": "example username",
          "email": "example@mail.com"
      }

  JSON Parameters:
  | id (integer) – ID(readOnly=True) is_active (boolean) – Is active(default=True) username (string) – Username(description=Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only., pattern=^[w.@+-]+$, maxLength=150, minLength=1) email (email) – Email(minLength=1)

param integer pk(required):
| A unique integer value identifying this user.
query schema data(required):
| User Schema

`GET` `/user/{pk}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 200 OK
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "offline": {
                  "active": true
              },
              "error": {
                  "active": true
              },
              "delay": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              }
          },
          "widgetSettings": {
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwProjectsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              }
          },
          "autoupdateInterval": 15000
      }

  JSON Parameters:
  | chartLineSettings (object) – (ChartLineSettings Schema) widgetSettings (object) – (WidgetSettings Schema) autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer pk(required):
| A unique integer value identifying this user.

`POST` `/user/{pk}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 201 Created
      Vary: Action accepted.
      Content-Type: application/json

      {
          "chartLineSettings": {
              "offline": {
                  "active": true
              },
              "error": {
                  "active": true
              },
              "delay": {
                  "active": true
              },
              "interrupted": {
                  "active": true
              },
              "all_tasks": {
                  "active": true
              },
              "ok": {
                  "active": true
              }
          },
          "widgetSettings": {
              "pmwTemplatesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwChartWidget": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwGroupsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwHostsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwInventoriesCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwProjectsCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              },
              "pmwUsersCounter": {
                  "collapse": true,
                  "active": true,
                  "sort": 1
              }
          },
          "autoupdateInterval": 15000
      }

  JSON Parameters:
  | chartLineSettings (object) – (ChartLineSettings Schema) widgetSettings (object) – (WidgetSettings Schema) autoupdateInterval (integer) – Autoupdateinterval(default=15000)

param integer pk(required):
| A unique integer value identifying this user.
query schema data(required):
| UserSettings Schema

`DELETE` `/user/{pk}/settings/`

  Return user settings.

  Example Response

      HTTP/1.1 204 No Content
      Vary: Action accepted.
      Content-Type: application/json

      {}

param integer pk(required):
| A unique integer value identifying this user.

## Schemas Description

### ProjectTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer"
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "GIT",
>                 "TAR"
>             ]
>         }
>     }

### Error Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### OneProjectTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer"
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "description": {
>             "title": "Description",
>             "type": "string",
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "GIT",
>                 "TAR"
>             ]
>         },
>         "repository": {
>             "title": "Repository",
>             "type": "string",
>             "maxLength": 2048,
>             "minLength": 1
>         }
>     }

### ProjectTemplateCreate Schema

>     {
>         "project_id": {
>             "title": "Project id",
>             "type": "integer",
>             "readOnly": true,
>             "additionalProperties": {
>                 "redirect": true
>             }
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### Group Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "children": {
>             "title": "Children",
>             "type": "boolean",
>             "readOnly": true
>         }
>     }

### User Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         }
>     }

### GroupCreateMaster Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "children": {
>             "title": "Contains groups",
>             "type": "boolean",
>             "default": false
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

### OneGroup Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "children": {
>             "title": "Children",
>             "type": "boolean",
>             "readOnly": true
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

### SetOwner Schema

>     {
>         "user_id": {
>             "title": "New owner",
>             "type": "integer",
>             "format": "select2",
>             "additionalProperties": {
>                 "view_field": "username",
>                 "value_field": "id",
>                 "model": {
>                     "id": {
>                         "title": "ID",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "username": {
>                         "title": "Username",
>                         "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                         "type": "string",
>                         "pattern": "^[\\w.@+-]+$",
>                         "maxLength": 150,
>                         "minLength": 1
>                     },
>                     "is_active": {
>                         "title": "Is active",
>                         "type": "boolean",
>                         "default": true
>                     },
>                     "email": {
>                         "title": "Email",
>                         "type": "string",
>                         "format": "email",
>                         "minLength": 1
>                     }
>                 }
>             }
>         }
>     }

### InventoryVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "format": "autocomplete",
>             "enum": [
>                 "ansible_host",
>                 "ansible_port",
>                 "ansible_user",
>                 "ansible_connection",
>                 "ansible_ssh_pass",
>                 "ansible_ssh_private_key_file",
>                 "ansible_ssh_common_args",
>                 "ansible_sftp_extra_args",
>                 "ansible_scp_extra_args",
>                 "ansible_ssh_extra_args",
>                 "ansible_ssh_executable",
>                 "ansible_ssh_pipelining",
>                 "ansible_become",
>                 "ansible_become_method",
>                 "ansible_become_user",
>                 "ansible_become_pass",
>                 "ansible_become_exe",
>                 "ansible_become_flags",
>                 "ansible_shell_type",
>                 "ansible_python_interpreter",
>                 "ansible_ruby_interpreter",
>                 "ansible_perl_interpreter",
>                 "ansible_shell_executable"
>             ]
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "key",
>                 "types": {
>                     "ansible_become": "boolean",
>                     "ansible_become_pass": "password",
>                     "ansible_ssh_private_key_file": "secretfile",
>                     "ansible_port": "integer",
>                     "ansible_ssh_pass": "password"
>                 },
>                 "choices": {}
>             }
>         }
>     }

### Host Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "RANGE",
>                 "HOST"
>             ],
>             "default": "HOST"
>         }
>     }

### OneHost Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "RANGE",
>                 "HOST"
>             ],
>             "default": "HOST"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

### History Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer"
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "project": {
>             "title": "Project",
>             "type": "integer"
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer"
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time"
>         }
>     }

### OneHistory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer"
>         },
>         "project": {
>             "title": "Project",
>             "type": "integer"
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "maxLength": 256
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer"
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "execute_args": {
>             "title": "Execute args",
>             "type": "string",
>             "readOnly": true
>         },
>         "execution_time": {
>             "title": "Execution time",
>             "type": "integer",
>             "format": "uptime"
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "raw_args": {
>             "title": "Raw args",
>             "type": "string",
>             "minLength": 1
>         },
>         "raw_stdout": {
>             "title": "Raw stdout",
>             "type": "string",
>             "readOnly": true
>         },
>         "raw_inventory": {
>             "title": "Raw inventory",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### Empty Schema

>     {}

### ActionResponse Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### Data Schema

>     {}

### Hook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "HTTP",
>                 "SCRIPT"
>             ]
>         },
>         "when": {
>             "title": "When",
>             "type": "string",
>             "enum": [
>                 "on_execution",
>                 "after_execution",
>                 "on_user_add",
>                 "on_user_upd",
>                 "on_user_del",
>                 "on_object_add",
>                 "on_object_upd",
>                 "on_object_del"
>             ]
>         },
>         "enable": {
>             "title": "Enable",
>             "type": "boolean"
>         },
>         "recipients": {
>             "title": "Recipients",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### Inventory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         }
>     }

### OneInventory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

### InventoryImport Schema

>     {
>         "inventory_id": {
>             "title": "Inventory id",
>             "type": "integer",
>             "additionalProperties": {
>                 "redirect": true
>             }
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "minLength": 1
>         },
>         "raw_data": {
>             "title": "Raw data",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### Project Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Type",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "NEW",
>                 "WAIT_SYNC",
>                 "SYNC",
>                 "ERROR",
>                 "OK"
>             ],
>             "readOnly": true
>         }
>     }

### ProjectCreateMaster Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         },
>         "type": {
>             "title": "Repo type",
>             "type": "string",
>             "enum": [
>                 "GIT",
>                 "MANUAL",
>                 "TAR"
>             ],
>             "default": "MANUAL"
>         },
>         "repository": {
>             "title": "Repo url",
>             "type": "string",
>             "default": "MANUAL",
>             "minLength": 1
>         },
>         "repo_auth": {
>             "title": "Repo auth type",
>             "type": "string",
>             "format": "dynamic",
>             "default": "NONE",
>             "additionalProperties": {
>                 "field": "type",
>                 "types": {
>                     "GIT": "string",
>                     "MANUAL": "hidden",
>                     "TAR": "hidden"
>                 },
>                 "choices": {
>                     "GIT": [
>                         "NONE",
>                         "KEY",
>                         "PASSWORD"
>                     ]
>                 }
>             }
>         },
>         "auth_data": {
>             "title": "Repo auth data",
>             "type": "string",
>             "format": "dynamic",
>             "default": "",
>             "additionalProperties": {
>                 "field": "repo_auth",
>                 "types": {
>                     "NONE": "hidden",
>                     "PASSWORD": "password",
>                     "KEY": "secretfile"
>                 },
>                 "choices": {}
>             }
>         },
>         "branch": {
>             "title": "GIT branch/tag/SHA",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "type",
>                 "types": {
>                     "GIT": "string",
>                     "MANUAL": "hidden",
>                     "TAR": "hidden"
>                 },
>                 "choices": {}
>             }
>         }
>     }

### OneProject Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "repository": {
>             "title": "Repository",
>             "type": "string",
>             "default": "MANUAL",
>             "minLength": 1
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "NEW",
>                 "WAIT_SYNC",
>                 "SYNC",
>                 "ERROR",
>                 "OK"
>             ],
>             "readOnly": true
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "readOnly": true
>         },
>         "branch": {
>             "title": "Branch",
>             "type": "string",
>             "readOnly": true
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "readme_content": {
>             "title": "Information",
>             "type": "string",
>             "format": "html",
>             "readOnly": true
>         },
>         "execute_view_data": {}
>     }

### AnsibleModule Schema

>     {
>         "module": {
>             "title": "Module",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "view_field": "path",
>                 "value_field": "name",
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "path": {
>                         "title": "Path",
>                         "type": "string",
>                         "maxLength": 1024,
>                         "minLength": 1
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "readOnly": true
>                     }
>                 }
>             }
>         },
>         "extra_vars": {
>             "title": "Extra vars",
>             "description": "set additional variables as key=value or YAML/JSON, if filename prepend with @",
>             "type": "string"
>         },
>         "syntax_check": {
>             "title": "Syntax check",
>             "description": "perform a syntax check on the playbook, but do not execute it",
>             "type": "boolean",
>             "default": false
>         },
>         "sudo": {
>             "title": "Sudo",
>             "description": "run operations with sudo (nopasswd) (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "ssh_extra_args": {
>             "title": "Ssh extra args",
>             "description": "specify extra arguments to pass to ssh only (e.g. -R)",
>             "type": "string"
>         },
>         "sudo_user": {
>             "title": "Sudo user",
>             "description": "desired sudo user (default=root) (deprecated, use become)",
>             "type": "string"
>         },
>         "key_file": {
>             "title": "Key file",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "diff": {
>             "title": "Diff",
>             "description": "when changing (small) files and templates, show the differences in those files; works great with --check",
>             "type": "boolean",
>             "default": false
>         },
>         "playbook_dir": {
>             "title": "Playbook dir",
>             "description": "Since this tool does not use playbooks, use this as a subsitute playbook directory.This sets the relative path for many features including roles/ group_vars/ etc.",
>             "type": "string"
>         },
>         "check": {
>             "title": "Check",
>             "description": "don't make any changes; instead, try to predict some of the changes that may occur",
>             "type": "boolean",
>             "default": false
>         },
>         "verbose": {
>             "title": "Verbose",
>             "description": "verbose mode (-vvv for more, -vvvv to enable connection debugging)",
>             "type": "integer",
>             "default": 0,
>             "maximum": 4
>         },
>         "poll": {
>             "title": "Poll",
>             "description": "set the poll interval if using -B (default=15)",
>             "type": "integer"
>         },
>         "group": {
>             "title": "Group",
>             "type": "string",
>             "default": "all"
>         },
>         "scp_extra_args": {
>             "title": "Scp extra args",
>             "description": "specify extra arguments to pass to scp only (e.g. -l)",
>             "type": "string"
>         },
>         "become_method": {
>             "title": "Become method",
>             "description": "privilege escalation method to use (default=sudo), valid choices: [ sudo | su | pbrun | pfexec | doas | dzdo | ksu | runas | pmrun | enable | machinectl ]",
>             "type": "string"
>         },
>         "become_user": {
>             "title": "Become user",
>             "description": "run operations as this user (default=root)",
>             "type": "string"
>         },
>         "connection": {
>             "title": "Connection",
>             "description": "connection type to use (default=smart)",
>             "type": "string"
>         },
>         "one_line": {
>             "title": "One line",
>             "description": "condense output",
>             "type": "boolean",
>             "default": false
>         },
>         "inventory": {
>             "title": "Inventory",
>             "description": "specify inventory host path or comma separated host list. --inventory-file is deprecated",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "view_field": "name",
>                 "value_field": "id",
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 512,
>                         "minLength": 1
>                     }
>                 }
>             }
>         },
>         "forks": {
>             "title": "Forks",
>             "description": "specify number of parallel processes to use (default=5)",
>             "type": "integer"
>         },
>         "vault_id": {
>             "title": "Vault id",
>             "description": "the vault identity to use",
>             "type": "string"
>         },
>         "list_hosts": {
>             "title": "List hosts",
>             "description": "outputs a list of matching hosts; does not execute anything else",
>             "type": "boolean",
>             "default": false
>         },
>         "private_key": {
>             "title": "Private key",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "args": {
>             "title": "Args",
>             "description": "module arguments",
>             "type": "string"
>         },
>         "sftp_extra_args": {
>             "title": "Sftp extra args",
>             "description": "specify extra arguments to pass to sftp only (e.g. -f, -l)",
>             "type": "string"
>         },
>         "user": {
>             "title": "User",
>             "description": "connect as this user (default=None)",
>             "type": "string"
>         },
>         "background": {
>             "title": "Background",
>             "description": "run asynchronously, failing after X seconds (default=N/A)",
>             "type": "integer"
>         },
>         "module_path": {
>             "title": "Module path",
>             "description": "prepend colon-separated path(s) to module library (default=[u'/home/grey/.ansible/plugins/modules', u'/usr/share/ansible/plugins/modules'])",
>             "type": "string"
>         },
>         "tree": {
>             "title": "Tree",
>             "description": "log output to this directory",
>             "type": "string"
>         },
>         "ssh_common_args": {
>             "title": "Ssh common args",
>             "description": "specify common arguments to pass to sftp/scp/ssh (e.g. ProxyCommand)",
>             "type": "string"
>         },
>         "su": {
>             "title": "Su",
>             "description": "run operations with su (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "vault_password_file": {
>             "title": "Vault password file",
>             "description": "vault password file",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "limit": {
>             "title": "Limit",
>             "description": "further limit selected hosts to an additional pattern",
>             "type": "string"
>         },
>         "timeout": {
>             "title": "Timeout",
>             "description": "override the connection timeout in seconds (default=10)",
>             "type": "integer"
>         },
>         "become": {
>             "title": "Become",
>             "description": "run operations with become (does not imply password prompting)",
>             "type": "boolean",
>             "default": false
>         },
>         "su_user": {
>             "title": "Su user",
>             "description": "run operations with su as this user (default=None) (deprecated, use become)",
>             "type": "string"
>         }
>     }

### ExecuteResponse Schema

>     {
>         "detail": {
>             "title": "Detail",
>             "type": "string",
>             "minLength": 1
>         },
>         "history_id": {
>             "title": "History id",
>             "type": "integer",
>             "additionalProperties": {
>                 "redirect": true
>             }
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer"
>         }
>     }

### AnsiblePlaybook Schema

>     {
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "view_field": "name",
>                 "value_field": "playbook",
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 251,
>                         "minLength": 1
>                     },
>                     "playbook": {
>                         "title": "Playbook",
>                         "type": "string",
>                         "maxLength": 256,
>                         "minLength": 1
>                     }
>                 }
>             }
>         },
>         "flush_cache": {
>             "title": "Flush cache",
>             "description": "clear the fact cache for every host in inventory",
>             "type": "boolean",
>             "default": false
>         },
>         "ssh_extra_args": {
>             "title": "Ssh extra args",
>             "description": "specify extra arguments to pass to ssh only (e.g. -R)",
>             "type": "string"
>         },
>         "extra_vars": {
>             "title": "Extra vars",
>             "description": "set additional variables as key=value or YAML/JSON, if filename prepend with @",
>             "type": "string"
>         },
>         "syntax_check": {
>             "title": "Syntax check",
>             "description": "perform a syntax check on the playbook, but do not execute it",
>             "type": "boolean",
>             "default": false
>         },
>         "sudo": {
>             "title": "Sudo",
>             "description": "run operations with sudo (nopasswd) (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "list_tags": {
>             "title": "List tags",
>             "description": "list all available tags",
>             "type": "boolean",
>             "default": false
>         },
>         "module_path": {
>             "title": "Module path",
>             "description": "prepend colon-separated path(s) to module library (default=[u'/home/grey/.ansible/plugins/modules', u'/usr/share/ansible/plugins/modules'])",
>             "type": "string"
>         },
>         "sudo_user": {
>             "title": "Sudo user",
>             "description": "desired sudo user (default=root) (deprecated, use become)",
>             "type": "string"
>         },
>         "skip_tags": {
>             "title": "Skip tags",
>             "description": "only run plays and tasks whose tags do not match these values",
>             "type": "string"
>         },
>         "key_file": {
>             "title": "Key file",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "diff": {
>             "title": "Diff",
>             "description": "when changing (small) files and templates, show the differences in those files; works great with --check",
>             "type": "boolean",
>             "default": false
>         },
>         "check": {
>             "title": "Check",
>             "description": "don't make any changes; instead, try to predict some of the changes that may occur",
>             "type": "boolean",
>             "default": false
>         },
>         "verbose": {
>             "title": "Verbose",
>             "description": "verbose mode (-vvv for more, -vvvv to enable connection debugging)",
>             "type": "integer",
>             "default": 0,
>             "maximum": 4
>         },
>         "scp_extra_args": {
>             "title": "Scp extra args",
>             "description": "specify extra arguments to pass to scp only (e.g. -l)",
>             "type": "string"
>         },
>         "become_method": {
>             "title": "Become method",
>             "description": "privilege escalation method to use (default=sudo), valid choices: [ sudo | su | pbrun | pfexec | doas | dzdo | ksu | runas | pmrun | enable | machinectl ]",
>             "type": "string"
>         },
>         "become_user": {
>             "title": "Become user",
>             "description": "run operations as this user (default=root)",
>             "type": "string"
>         },
>         "connection": {
>             "title": "Connection",
>             "description": "connection type to use (default=smart)",
>             "type": "string"
>         },
>         "list_tasks": {
>             "title": "List tasks",
>             "description": "list all tasks that would be executed",
>             "type": "boolean",
>             "default": false
>         },
>         "inventory": {
>             "title": "Inventory",
>             "description": "specify inventory host path or comma separated host list. --inventory-file is deprecated",
>             "type": "string",
>             "format": "autocomplete",
>             "additionalProperties": {
>                 "view_field": "name",
>                 "value_field": "id",
>                 "model": {
>                     "id": {
>                         "title": "Id",
>                         "type": "integer",
>                         "readOnly": true
>                     },
>                     "name": {
>                         "title": "Name",
>                         "type": "string",
>                         "maxLength": 512,
>                         "minLength": 1
>                     }
>                 }
>             }
>         },
>         "forks": {
>             "title": "Forks",
>             "description": "specify number of parallel processes to use (default=5)",
>             "type": "integer"
>         },
>         "vault_id": {
>             "title": "Vault id",
>             "description": "the vault identity to use",
>             "type": "string"
>         },
>         "list_hosts": {
>             "title": "List hosts",
>             "description": "outputs a list of matching hosts; does not execute anything else",
>             "type": "boolean",
>             "default": false
>         },
>         "tags": {
>             "title": "Tags",
>             "description": "only run plays and tasks tagged with these values",
>             "type": "string"
>         },
>         "private_key": {
>             "title": "Private key",
>             "description": "use this file to authenticate the connection",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "step": {
>             "title": "Step",
>             "description": "one-step-at-a-time: confirm each task before running",
>             "type": "boolean",
>             "default": false
>         },
>         "sftp_extra_args": {
>             "title": "Sftp extra args",
>             "description": "specify extra arguments to pass to sftp only (e.g. -f, -l)",
>             "type": "string"
>         },
>         "user": {
>             "title": "User",
>             "description": "connect as this user (default=None)",
>             "type": "string"
>         },
>         "force_handlers": {
>             "title": "Force handlers",
>             "description": "run handlers even if a task fails",
>             "type": "boolean",
>             "default": false
>         },
>         "start_at_task": {
>             "title": "Start at task",
>             "description": "start the playbook at the task matching this name",
>             "type": "string"
>         },
>         "ssh_common_args": {
>             "title": "Ssh common args",
>             "description": "specify common arguments to pass to sftp/scp/ssh (e.g. ProxyCommand)",
>             "type": "string"
>         },
>         "su": {
>             "title": "Su",
>             "description": "run operations with su (deprecated, use become)",
>             "type": "boolean",
>             "default": false
>         },
>         "vault_password_file": {
>             "title": "Vault password file",
>             "description": "vault password file",
>             "type": "string",
>             "format": "secretfile"
>         },
>         "limit": {
>             "title": "Limit",
>             "description": "further limit selected hosts to an additional pattern",
>             "type": "string"
>         },
>         "timeout": {
>             "title": "Timeout",
>             "description": "override the connection timeout in seconds (default=10)",
>             "type": "integer"
>         },
>         "become": {
>             "title": "Become",
>             "description": "run operations with become (does not imply password prompting)",
>             "type": "boolean",
>             "default": false
>         },
>         "su_user": {
>             "title": "Su user",
>             "description": "run operations with su as this user (default=None) (deprecated, use become)",
>             "type": "string"
>         }
>     }

### ProjectHistory Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "start_time": {
>             "title": "Start time",
>             "type": "string",
>             "format": "date-time"
>         },
>         "executor": {
>             "title": "Executor",
>             "type": "integer"
>         },
>         "initiator": {
>             "title": "Initiator",
>             "type": "integer"
>         },
>         "initiator_type": {
>             "title": "Initiator type",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "revision": {
>             "title": "Revision",
>             "type": "string",
>             "maxLength": 256
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "integer"
>         },
>         "kind": {
>             "title": "Kind",
>             "type": "string",
>             "maxLength": 50,
>             "minLength": 1
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         },
>         "options": {
>             "title": "Options",
>             "type": "string",
>             "readOnly": true
>         },
>         "status": {
>             "title": "Status",
>             "type": "string",
>             "enum": [
>                 "DELAY",
>                 "RUN",
>                 "OK",
>                 "ERROR",
>                 "OFFLINE",
>                 "INTERRUPTED"
>             ]
>         },
>         "stop_time": {
>             "title": "Stop time",
>             "type": "string",
>             "format": "date-time"
>         }
>     }

### Module Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "path": {
>             "title": "Path",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "readOnly": true
>         }
>     }

### OneModule Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "path": {
>             "title": "Path",
>             "type": "string",
>             "maxLength": 1024,
>             "minLength": 1
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "readOnly": true
>         },
>         "data": {}
>     }

### Periodictask Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Task type",
>             "type": "string",
>             "enum": [
>                 "PLAYBOOK",
>                 "MODULE",
>                 "TEMPLATE"
>             ],
>             "default": "PLAYBOOK"
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "autocomplete",
>                     "PLAYBOOK": "autocomplete",
>                     "TEMPLATE": "hidden"
>                 },
>                 "choices": {}
>             }
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "select2",
>                     "PLAYBOOK": "select2",
>                     "TEMPLATE": "hidden"
>                 },
>                 "choices": {}
>             }
>         },
>         "save_result": {
>             "title": "Save result",
>             "type": "boolean"
>         },
>         "template": {
>             "title": "Template",
>             "type": "integer"
>         },
>         "template_opt": {
>             "title": "Template opt",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "hidden",
>                     "PLAYBOOK": "hidden",
>                     "TEMPLATE": "autocomplete"
>                 },
>                 "choices": {}
>             }
>         },
>         "enabled": {
>             "title": "Enabled",
>             "type": "boolean"
>         },
>         "type": {
>             "title": "Interval type",
>             "type": "string",
>             "enum": [
>                 "CRONTAB",
>                 "INTERVAL"
>             ],
>             "default": "CRONTAB"
>         },
>         "schedule": {
>             "title": "Schedule",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "type",
>                 "types": {
>                     "INTERVAL": "integer",
>                     "CRONTAB": "crontab"
>                 },
>                 "choices": {}
>             }
>         }
>     }

### OnePeriodictask Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Task type",
>             "type": "string",
>             "enum": [
>                 "PLAYBOOK",
>                 "MODULE",
>                 "TEMPLATE"
>             ],
>             "default": "PLAYBOOK"
>         },
>         "mode": {
>             "title": "Mode",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "autocomplete",
>                     "PLAYBOOK": "autocomplete",
>                     "TEMPLATE": "hidden"
>                 },
>                 "choices": {}
>             }
>         },
>         "inventory": {
>             "title": "Inventory",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "select2",
>                     "PLAYBOOK": "select2",
>                     "TEMPLATE": "hidden"
>                 },
>                 "choices": {}
>             }
>         },
>         "save_result": {
>             "title": "Save result",
>             "type": "boolean"
>         },
>         "template": {
>             "title": "Template",
>             "type": "integer"
>         },
>         "template_opt": {
>             "title": "Template opt",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "kind",
>                 "types": {
>                     "MODULE": "hidden",
>                     "PLAYBOOK": "hidden",
>                     "TEMPLATE": "autocomplete"
>                 },
>                 "choices": {}
>             }
>         },
>         "enabled": {
>             "title": "Enabled",
>             "type": "boolean"
>         },
>         "type": {
>             "title": "Interval type",
>             "type": "string",
>             "enum": [
>                 "CRONTAB",
>                 "INTERVAL"
>             ],
>             "default": "CRONTAB"
>         },
>         "schedule": {
>             "title": "Schedule",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "type",
>                 "types": {
>                     "INTERVAL": "integer",
>                     "CRONTAB": "crontab"
>                 },
>                 "choices": {}
>             }
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         }
>     }

### PeriodicTaskVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "default": ""
>         }
>     }

### Playbook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 251,
>             "minLength": 1
>         },
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "maxLength": 256,
>             "minLength": 1
>         }
>     }

### OnePlaybook Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 251,
>             "minLength": 1
>         },
>         "playbook": {
>             "title": "Playbook",
>             "type": "string",
>             "readOnly": true,
>             "minLength": 1
>         }
>     }

### Template Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "kind": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "Task",
>                 "Module"
>             ],
>             "default": "Task"
>         },
>         "data": {},
>         "options": {},
>         "options_list": {
>             "type": "array",
>             "items": {
>                 "type": "string"
>             },
>             "readOnly": true
>         }
>     }

### OneTemplate Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 512,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "kind": {
>             "title": "Type",
>             "type": "string",
>             "enum": [
>                 "Task",
>                 "Module"
>             ],
>             "default": "Task"
>         },
>         "data": {},
>         "options": {},
>         "options_list": {
>             "type": "array",
>             "items": {
>                 "type": "string"
>             },
>             "readOnly": true
>         }
>     }

### TemplateExec Schema

>     {
>         "option": {
>             "title": "Option",
>             "description": "Option name from template options.",
>             "type": "string",
>             "minLength": 0
>         }
>     }

### ProjectVariable Schema

>     {
>         "id": {
>             "title": "Id",
>             "type": "integer",
>             "readOnly": true
>         },
>         "key": {
>             "title": "Key",
>             "type": "string",
>             "enum": [
>                 "repo_type",
>                 "repo_sync_on_run",
>                 "repo_branch",
>                 "repo_password",
>                 "repo_key"
>             ]
>         },
>         "value": {
>             "title": "Value",
>             "type": "string",
>             "format": "dynamic",
>             "additionalProperties": {
>                 "field": "key",
>                 "types": {
>                     "repo_key": "secretfile",
>                     "repo_password": "password"
>                 },
>                 "choices": {
>                     "repo_type": [
>                         "GIT",
>                         "MANUAL",
>                         "TAR"
>                     ],
>                     "repo_sync_on_run": [
>                         true,
>                         false
>                     ]
>                 }
>             }
>         }
>     }

### Team Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 80,
>             "minLength": 1
>         }
>     }

### OneTeam Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "name": {
>             "title": "Name",
>             "type": "string",
>             "maxLength": 80,
>             "minLength": 1
>         },
>         "notes": {
>             "title": "Notes",
>             "type": "string",
>             "format": "textarea"
>         },
>         "owner": {
>             "id": {
>                 "title": "ID",
>                 "type": "integer",
>                 "readOnly": true
>             },
>             "username": {
>                 "title": "Username",
>                 "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>                 "type": "string",
>                 "pattern": "^[\\w.@+-]+$",
>                 "maxLength": 150,
>                 "minLength": 1
>             },
>             "is_active": {
>                 "title": "Is active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "email": {
>                 "title": "Email",
>                 "type": "string",
>                 "format": "email",
>                 "minLength": 1
>             }
>         }
>     }

### CreateUser Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "first_name": {
>             "title": "First name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "last_name": {
>             "title": "Last name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         },
>         "password": {
>             "title": "Password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password2": {
>             "title": "Repeat password",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### OneUser Schema

>     {
>         "id": {
>             "title": "ID",
>             "type": "integer",
>             "readOnly": true
>         },
>         "username": {
>             "title": "Username",
>             "description": "Required. 150 characters or fewer. Letters, digits and @/./+/-/_ only.",
>             "type": "string",
>             "pattern": "^[\\w.@+-]+$",
>             "maxLength": 150,
>             "minLength": 1
>         },
>         "is_active": {
>             "title": "Is active",
>             "type": "boolean",
>             "default": true
>         },
>         "first_name": {
>             "title": "First name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "last_name": {
>             "title": "Last name",
>             "type": "string",
>             "maxLength": 30
>         },
>         "email": {
>             "title": "Email",
>             "type": "string",
>             "format": "email",
>             "minLength": 1
>         }
>     }

### ChangePassword Schema

>     {
>         "old_password": {
>             "title": "Old password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password": {
>             "title": "New password",
>             "type": "string",
>             "minLength": 1
>         },
>         "password2": {
>             "title": "Confirm new password",
>             "type": "string",
>             "minLength": 1
>         }
>     }

### ChartLineSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         }
>     }

### ChartLineSettings Schema

>     {
>         "all_tasks": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "delay": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "ok": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "error": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "interrupted": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         },
>         "offline": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             }
>         }
>     }

### CounterWidgetSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         },
>         "collapse": {
>             "title": "Collapse",
>             "type": "boolean",
>             "readOnly": true,
>             "default": false
>         },
>         "sort": {
>             "title": "Sort",
>             "type": "integer",
>             "default": 0
>         }
>     }

### WidgetSetting Schema

>     {
>         "active": {
>             "title": "Active",
>             "type": "boolean",
>             "default": true
>         },
>         "collapse": {
>             "title": "Collapse",
>             "type": "boolean",
>             "default": false
>         },
>         "sort": {
>             "title": "Sort",
>             "type": "integer",
>             "default": 0
>         }
>     }

### WidgetSettings Schema

>     {
>         "pmwUsersCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwProjectsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwTemplatesCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwInventoriesCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwGroupsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwHostsCounter": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "readOnly": true,
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         },
>         "pmwChartWidget": {
>             "active": {
>                 "title": "Active",
>                 "type": "boolean",
>                 "default": true
>             },
>             "collapse": {
>                 "title": "Collapse",
>                 "type": "boolean",
>                 "default": false
>             },
>             "sort": {
>                 "title": "Sort",
>                 "type": "integer",
>                 "default": 0
>             }
>         }
>     }

### UserSettings Schema

>     {
>         "autoupdateInterval": {
>             "title": "Autoupdateinterval",
>             "type": "integer",
>             "default": 15000
>         },
>         "chartLineSettings": {
>             "all_tasks": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "delay": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "ok": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "error": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "interrupted": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             },
>             "offline": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 }
>             }
>         },
>         "widgetSettings": {
>             "pmwUsersCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwProjectsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwTemplatesCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwInventoriesCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwGroupsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwHostsCounter": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "readOnly": true,
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             },
>             "pmwChartWidget": {
>                 "active": {
>                     "title": "Active",
>                     "type": "boolean",
>                     "default": true
>                 },
>                 "collapse": {
>                     "title": "Collapse",
>                     "type": "boolean",
>                     "default": false
>                 },
>                 "sort": {
>                     "title": "Sort",
>                     "type": "integer",
>                     "default": 0
>                 }
>             }
>         }
>     }